#
# spec file for package python-funcy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-funcy
Version:        2.0
Release:        1.3
Summary:        Functional tools for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Suor/funcy
Source:         https://files.pythonhosted.org/packages/source/f/funcy/funcy-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module whatever}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A collection of functional tools focused on practicality.

Inspired by clojure, underscore and the author's own abstractions.

%prep
%setup -q -n funcy-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm -r tests/__pycache__
%pytest

%files %{python_files}
%doc CHANGELOG README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Dec 11 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0:
  * added get_lax()
  * added lzip(strict) param
  * made autocurry() and friends support kw-only and pos-only
    arguments
  * improved call._whatever_ arg introspection: pos-only, kw-
    only, kwargs and varargs are supported
  * test against Python 3.11
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 1.18:
  * added join_with(strict=)
  * use more precise timer `timeit.default_timer` for
    log*durations (Saugat Pachhai)
  * preserve metadata when using autocurry as a decorator
  * doc improvements (thx to Tim Gates)
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.17
  - added del_in()
  - made throttle() and limit_error_rate() work on methods
  - added str and repr to Call objects
  - migrated CI to Github actions (thx to Bruno Alla)
  - fixed doc[string] for zip_dicts (Tal Einat)
  - fixed some inspect issues
  - minor doc fixes
* Tue Aug 31 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.16
  * support Python 3.9 officially
  * unify @memoize() and @cache(): both have .skip/.memory/.invalidate/.invalidate_all now
  * support dynamic resulting exception in @reraise() (Laurens Duijvesteijn)
  * made () optional for @decorator-made decorators with kw-only args
  * added @throttle()
  * added has_path() (Denys Zorinets)
  * fixed autocurry kwargs handling
- from version 1.15
  * made rpartial accept keyworded arguments (Ruan Comelli)
  * made `@cache.invalidate()` idempotent (Dmitry Vasilyanov)
  * made raiser() accept a string as a shortcut
  * fixed cheatsheat description for 'distinct' helper (tsouvarev)
  * fixed some seqs docstrings
  * fixed some typos (Tim Gates)
* Sun Aug  9 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.14
  * stated Python 3.7 and 3.8 support
  * dropped Python 2.6
  * added @wrap_prop()
  * added filter_errors param to @retry()
  * published nullcontext properly
* Mon Aug 12 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.13
  * added @wrap_with()
  * added nullcontext
* Fri May 10 2019 pgajdos@suse.com
- version update to 1.12
  - added @cached_readonly
  - more introspection in @decorator decorators
  - documented @cached_property inheritance limitations
  - included tests in pypi sdist tarball (Tomáš Chvátal)
- back to PyPI tarball
* Tue Mar 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.11:
  - switched docs and internals to Python 3
  - improved docs: better texts and examples here and there
  - support Python 3.7 officially
  - added popups over functions everywhere in docs
  - accept any iterables of errors in flow utils
  - fixed walk_values() for defaultdicts with empty factory
  - fixed xmap() signature introspection
  - documented lzip()
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri May 18 2018 jengelh@inai.de
- Avoid first person in description.
* Wed May  9 2018 toddrme2178@gmail.com
- Update to 1.10.1
  * use raise from in reraise()
  * fix @cache with mixed positional and keywords args (thx to adrian-dankiv)
- Update to 1.10
  * added @reraise()
  * added unit and threshold params to *_durations() utils
  * published and documented LazyObject
  * fixed iffy() default argument when action is not present (Dmytro Kabakchei)
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to 1.9.1
  * See changelog at https://github.com/Suor/funcy/blob/1.9.1/CHANGELOG
* Mon Jul 14 2014 toddrme2178@gmail.com
- - Initial version
